pub fn component_get_mut_impl(
context_id: GoudContextId,
entity_id: GoudEntityId,
type_id_hash: u64,
) -> *mut u8Expand description
Gets a mutable pointer to a component on an entity.
pub fn component_get_mut_impl(
context_id: GoudContextId,
entity_id: GoudEntityId,
type_id_hash: u64,
) -> *mut u8Gets a mutable pointer to a component on an entity.