component_has_batch_impl

Function component_has_batch_impl 

pub unsafe fn component_has_batch_impl(
    context_id: GoudContextId,
    entity_ids: *const u64,
    count: u32,
    type_id_hash: u64,
    out_results: *mut u8,
) -> u32
Checks if multiple entities have a specific component type.

Safety

  • entity_ids must point to valid memory with count u64 values
  • out_results must point to valid memory with count u8 values