PluginGroup

Trait PluginGroup 

pub trait PluginGroup {
    // Required method
    fn build(self, app: &mut App);
}
A group of plugins that can be added to an App together.

Plugin groups provide a convenient way to add multiple related plugins at once.

Required Methods

fn build(self, app: &mut App)

Adds all plugins in this group to the app.

Implementors