pub struct WriteAccess(pub ComponentId);Expand description
Marker type for tracking write access to a component.
Used to distinguish between read and write access in conflict detection. This allows the query system to detect when two queries would violate Rust’s aliasing rules (one mutable + any other access to same component).
Tuple Fields
0: ComponentIdTrait Implementations
Sourceimpl Clone for WriteAccess
impl Clone for WriteAccess
Sourcefn clone(&self) -> WriteAccess
fn clone(&self) -> WriteAccess
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WriteAccess
impl Debug for WriteAccess
Sourceimpl Hash for WriteAccess
impl Hash for WriteAccess
Sourceimpl Ord for WriteAccess
impl Ord for WriteAccess
Sourcefn cmp(&self, other: &WriteAccess) -> Ordering
fn cmp(&self, other: &WriteAccess) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WriteAccess
impl PartialEq for WriteAccess
Sourceimpl PartialOrd for WriteAccess
impl PartialOrd for WriteAccess
impl Copy for WriteAccess
impl Eq for WriteAccess
impl StructuralPartialEq for WriteAccess