pub unsafe fn component_remove_batch_impl(
context_id: GoudContextId,
entity_ids: *const u64,
count: u32,
type_id_hash: u64,
) -> u32Expand description
Removes the same component type from multiple entities in a batch.
Safety
entity_ids must point to valid memory with count u64 values.