pub trait PluginGroup {
// Required method
fn build(self, app: &mut App);
}Expand description
A group of plugins that can be added to an App together.
Plugin groups provide a convenient way to add multiple related plugins at once.
pub trait PluginGroup {
// Required method
fn build(self, app: &mut App);
}A group of plugins that can be added to an App together.
Plugin groups provide a convenient way to add multiple related plugins at once.