pub enum SystemOrdering {
Before {
system: SystemId,
before: SystemId,
},
After {
system: SystemId,
after: SystemId,
},
}Expand description
Specifies an ordering constraint between two systems.
Ordering constraints are used to ensure systems run in a specific order, regardless of the order they were added to the stage.
Example
use goud_engine::ecs::schedule::SystemOrdering;
use goud_engine::ecs::system::SystemId;
let ordering = SystemOrdering::Before {
system: SystemId::from_raw(1),
before: SystemId::from_raw(2),
};Variants
Implementations
Sourceimpl SystemOrdering
impl SystemOrdering
Sourcepub fn before(system: SystemId, other: SystemId) -> Self
pub fn before(system: SystemId, other: SystemId) -> Self
Creates a constraint where system runs before other.
Sourcepub fn after(system: SystemId, other: SystemId) -> Self
pub fn after(system: SystemId, other: SystemId) -> Self
Creates a constraint where system runs after other.
Sourcepub fn first(&self) -> SystemId
pub fn first(&self) -> SystemId
Returns the system that must run first according to this constraint.
Sourcepub fn second(&self) -> SystemId
pub fn second(&self) -> SystemId
Returns the system that must run second according to this constraint.